from api import client
import requests
from urllib.parse import urljoin
import os
import re
lettersNotToReplace = "1234567890QWERTYUIOPASDFGHJKLZXCVBNMqwertyuiopasdfghjklzxcvbnm_"
templateFile = open("template.html")
template = templateFile.read()
templateFile.close()

def turnListIntoReadable(data):
    dataString = ""
    for datum in data:
        if data.index(datum) == len(data)-1:
            dataString += "and " + datum
        else:
            dataString += datum + ", "
    return dataString


def turnReadableCategories(category):
    categoryLists = []
    possCats = {1: "Coding", 2:"User Interface", 3:"Documentation & Training", 4: "Quality Assurance", 5: "Outreach & Research"}
    for possCat in possCats:
        if possCat == category:
           categoryLists.append(possCats[possCat])
    return turnListIntoReadable(categoryLists)


def generateHtmlFile(name, description, date, timeToComplete, mentors, status, tags, categories, directory):
    global template
    directory = os.path.dirname(os.path.realpath(__file__)) + directory
    substitutes = {"name": name,
                   "description": description,
                   "time": str(timeToComplete) + " days to complete",
                   "status": "Draft" if status == 1 else "Published",
                   "date": date,
                   "mentors": turnListIntoReadable(mentors),
                   "tags": turnListIntoReadable(tags),
                   "cats": turnReadableCategories(categories)}
    htmlToWrite = template

    for substitute in substitutes:
        htmlToWrite = htmlToWrite.replace(substitute, substitutes[substitute])

    file = open(directory + "index.html", "w")
    file.write(htmlToWrite)
    file.close()


def createDirectoryInLocalDirectory(path):
    """
    Say your code is in in /a/b
    When you call this with a path of say "/c" the code will essentially create a new directory as /a/b/c
    """
    modifiedPath = ""
    for letter in path: modifiedPath += "" if letter not in lettersNotToReplace else letter
    path = "/" + modifiedPath #Just don't want to change the code below
    directoryToMakeIn = os.path.dirname(os.path.realpath(__file__)) + path
    if not os.path.exists(directoryToMakeIn + path):
        os.makedirs(directoryToMakeIn + path)

#Dummy data for my testing
#createDirectoryInLocalDirectory("/testingDeleteMe / yay")
#generateHtmlFile("Name", "Description", "date", 1, ["mentor1","mentor2", "mentor3"], "status", "Tags", "categories", "/testingDeleteMe")

if __name__ == "__main__":
    #My own code
    authToken = input("Auth token:")
    clientObj = client.GCIAPIClient(auth_token=authToken)
    tasks = clientObj.ListTasks()

    #Taken off the Git Repo's list_instances code
    next_page = 1
    while next_page > 0:
        tasks = clientObj.ListTasks(page=next_page)

        #Iterates through and creates a directory and HTML file for each task
        for t in tasks['results']:
            blankString = ""
            directoryName = t["last_modified"] + "-" + t["name"].replace(" ", "_")
            for letter in directoryName: blankString += "" if letter not in lettersNotToReplace else letter
            directoryName = blankString
            createDirectoryInLocalDirectory(directoryName)
            generateHtmlFile(t["name"],
                             t["description"],
                             t["last_modified"],
                             t["time_to_complete_in_days"],
                             t["mentors"],
                             t["status"],
                             t["tags"],
                             t["categories"],
                             directoryName)


        next_page = 0
        if tasks['next']:
          result = re.search(r'page=(\d+)', tasks['next'])
          if result:
            next_page = int(result.group(1))
